@@ -3,7 +3,7 @@
  * color.h
  * 
  *
- * Copyright (C) 2003 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 2003, 2006 Staf Wagemakers Belgie/Belgium
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,18 +15,18 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
 #ifndef __COLOR_H
 #define __COLOR_H
 
+#include "common.h"
 #include "xstring.h"
-#include "xmalloc.h"
-#include <ncurses.h>
+#include "ncurses_h.h"
 #include <stdio.h>
 #include "configfile.h"
 
