@@ -1,7 +1,7 @@
 /*
  *  configfile.h
  *
- *  Copyright (C) 1999,2001  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1999, 2001, 2006  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,21 +13,20 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
 #ifndef _STAF_CONFIGFILE_H
 #define _STAF_CONFIGFILE_H
 
+#include "common.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <errno.h>
 #include "xstring.h"
-#include "xmalloc.h"
 
 char * get_config(FILE *fp,char *var_name);
 char * get_config_item(FILE *fp,char *var_name);
