@@ -1,7 +1,7 @@
 /*
  *  eng.h
  *
- *  Copyright (C) 1997, 1998, 2000, 2001, 2002, 2003, 2004, 2006, 2011, 2012  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997 - 2015  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ const char sel_hm		='h';
 const int sel_om                ='o';
 char *txt_help[]		= {
 "---------------------------------------------------------------------------",
-"lookat 1.4.3                                (GPL) 1997-2013 Belgie  Belgium",
+"lookat 1.4.4                                (GPL) 1997-2015 Belgie  Belgium",
 "                                                            Staf Wagemakers",
 "                                                  email: staf@wagemakers.be",
 " ",
@@ -37,7 +37,7 @@ char *txt_help[]		= {
 "- by typing 'lookat <dir_name>', change the current directory to <dir_name>.",
 "- by typing 'lookat <filename>', the file with <filename> will automatically",
 "  be loaded.",
-"- read form stdin",
+"- read from stdin",
 "  examples : lookat < test.txt",
 "             ls | lookat",
 "- use 'lookat' as a manual page viewer : man -Plookat ls",
@@ -60,8 +60,8 @@ int hkey_zm[]           ={'s','b','a'};
 int hkey_om[]           ={0,'n','t','c','s'};
 int hkey_hlp[]          ={'s','k','a'};
 unsigned hplace_bm[]         	={0,1,0,1,0,1};
-unsigned hplace_gm[]         	={3,1,3,1,3,1,19,5,19,6};
-unsigned hplace_zm[]         	={2,1,5,1,0,1};
+unsigned hplace_gm[]         	={3,1,3,1,3,1,21,5,21,6};
+unsigned hplace_zm[]         	={0,1,5,1,0,1};
 unsigned hplace_om[]         	={3,1,3,1,0,1,0,1}; 
 unsigned hplace_hlpm[]       	={0,1,0,1,0,1};
 unsigned hplace_hm[]         	={0,1,0,1,0,1,0,1,0,1};
@@ -78,7 +78,7 @@ unsigned hplace_type[]      	={4,1,2,1};
 
 char txt_info_open[]	="Select a file or directory     TAB = files <-> directories       ESC = cancel";
 char txt_term[]         ="Program terminated by signal ";
-char *txt_f_writecfg[]	={"Sorry, cant't write config file...\n",NULL};
+char *txt_f_writecfg[]	={"Sorry, can't write config file...\n",NULL};
 char txt_f_open1[]	="Sorry, I can't open : ";
 char txt_f_open2[]	="\n";
 char txt_f_laden[]	="No such file or directory...";
@@ -100,10 +100,10 @@ char txt_t_d[]          ="d          : PgDwn";
 char txt_t_o[]		="o          : open a file";
 char txt_t_zsf[]	="/,z,s,f    : search text";
 char txt_t_F3[]		="F3,n,c,v,\\ : continue search";
-char txt_t_HOME[]	="HOME,0,^   : go to the beginning of a line";
-char txt_t_END[]	="END        : go to the end of a line";
-char txt_t_b[]		="t,<        : go to begin of the file";
-char txt_t_e[]		="b,e,>      : go the end of the file";
+char txt_t_HOME[]	="HOME,0,^   : go to beginning of line";
+char txt_t_END[]	="END        : go to end of line";
+char txt_t_b[]		="t,<        : go to beginning of file";
+char txt_t_e[]		="b,e,>      : go to end of file";
 char txt_t_F9[]		="F9         : menu";
 char txt_t_help[]	="h,?,F1     : view help file";
 char txt_t_QUIT[]	="Q,ESC,F10  : quit program ... :-(";
@@ -130,8 +130,8 @@ char *txt_attributen[] = {"normal","bold","underline","reverse",
 char txt_ondersheid_g[]	="[ ] Case sensitive";
 char txt_search_back[]  ="[ ] Search backwards";
 char *txt_over[]	={
-"Lookat version 1.4.3               GNU Public License",
-"Staf Wagemakers                   (1997-2013) Belgium","\n",
+"Lookat version 1.4.4               GNU Public License",
+"Staf Wagemakers                   (1997-2015) Belgium","\n",
 "email:                             staf@wagemakers.be",
 "homepage:                    http://www.wagemakers.be","\n",NULL};
 char txt_bedank[]       ="Thank you for using this program!";
@@ -144,8 +144,8 @@ char txt_n_type[]	=" New type ... ";
 char txt_geef_de_tekst[]="String to search  : ";
 char txt_typename[]	="Type name   :";
 char txt_typeval[]	="Type value  :";
-char txt_ga_lijn[]	=" Go to a line ... ";
-char txt_geef_lijnnr[]	="Number of the line : ";
+char txt_ga_lijn[]	=" Go to line ... ";
+char txt_geef_lijnnr[]	="Line number : ";
 char txt_lijn[]		="line";
 char txt_kol[]		="col.";
 char txt_Grootte[]	="size";
@@ -168,16 +168,16 @@ char *txt_hm[]={"File","Go","Search","Options","Help"};
 char *txt_bm[]={"Open <o>",
 	        "Refresh screen <r>",
 		"Quit <F10,ESC,Q>"};
-char *txt_gm[]={"to top             <T>",
-                "to bottom          <B>",
-                "to line            <G>",
-                "to end of a line   <END>",
-                "to begin of a line <HOME>"};
-char *txt_zm[]={"a string   <Z,S,F>",
-                "form begin of the file",
-                "Again      <F3,n,c,v>"};
+char *txt_gm[]={"to top               <T>",
+                "to bottom            <B>",
+                "to line              <G>",
+                "to end of line       <END>",
+                "to beginning of line <HOME>"};
+char *txt_zm[]={"String      <Z,S,F>",
+                "from beginning of file",
+                "Again       <F3,n,c,v>"};
 char txt_om1[]="[ ] cursor";
-char txt_om2[]="[X] give notice";
+char txt_om2[]="[X] prompt";
 char *txt_om[]= {txt_om1,txt_om2,
 		  "Types",
 		  "Colors",
