@@ -1,7 +1,7 @@
 /*
  *  get_dir.c
  *
- *  Copyright (C) 1997,98  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997, 1998, 2006, 2007  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,20 +13,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
-#include <stddef.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <dirent.h>
 #include "get_dir.h"
-int compare(const char **c1,const char **c2)
+/* int compare(const char **c1,const char **c2)  */
+int compare(const void *e1, const void *e2) 
 {
+  char **c1=(char **) e1, **c2=(char **) e2;
   return strcmp (*c1,*c2);
 }
 struct dir_data* get_dir(char *path)
@@ -41,7 +38,7 @@ struct dir_data* get_dir(char *path)
   data=(struct dir_data*) xmalloc(sizeof(struct dir_data));
   data->file=data->dir=NULL;
   data->files=data->dirs=0;
-  while (ep=readdir(dp)) {
+  while ((ep=readdir(dp))) {
        s=(char *) xmalloc(strlen(path)+strlen(ep->d_name)+1);
        strcpy(s,path);
        strcat(s,ep->d_name);
