@@ -166,6 +166,9 @@ getstr (lineptr, n, stream, terminator, offset)
   return ret;
 }
 
+#ifndef __OpenBSD__
+#ifndef __NetBSD__
+
 int
 getline (lineptr, n, stream)
      char **lineptr;
@@ -193,4 +196,6 @@ getdelim (lineptr, n, delimiter, stream)
 }
 #endif
 
+#endif /* ifndef __NetBSD__ */
+#endif /* ifndef __OpenBSD__ */
 
