@@ -1,7 +1,7 @@
 /*
  *  input.c
  *
- *  Copyright (C) 1997,98,2000  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997, 1998, 2000, 2006  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -29,7 +29,7 @@
 /* unsigned i  -> positie in string          */
 /* char     cc -> karakter		     */
 /* ----------------------------------------- */
-ins_char (char *c,unsigned i,char cc)
+void ins_char (char *c,unsigned i,char cc)
 {
 unsigned x;
 unsigned einde=strlen(c);
@@ -50,7 +50,7 @@ c[einde+1]=0;
 /* P.S. Deze funktie schuift de kar's ook    */
 /* naar rechts!			             */
 /* ----------------------------------------- */
-del_char (char *c,unsigned i)
+void del_char (char *c,unsigned i)
 {
 unsigned x;
 for (x=i;x<strlen(c);x++) c[x]=c[x+1];
@@ -58,7 +58,7 @@ for (x=i;x<strlen(c);x++) c[x]=c[x+1];
 /* ----------------------------------------- */
 /* wissen van het huidige scherm entry       */
 /* ----------------------------------------- */
-wis (WINDOW *w,int yp,int xp,int n)
+void wis (WINDOW *w,int yp,int xp,int n)
 {
 int i;
 for (i=0;i<n;i++) mvwaddch(w,yp,xp+i,' ');
