@@ -1,7 +1,7 @@
 /*
  *  input.h
  *
- *  Copyright (C) 1997,98  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997, 1998, 2006  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,16 +13,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
 #ifndef __INPUT_H
 #define __INPUT_H
 #include "config.h"
-#include <ncurses.h>
+#include "common.h"
+#include "ncurses_h.h"
 typedef struct {
 	WINDOW *w;	/* input vensters				 */
 	int  yp,xp;	/* y,x positie in het venster w			 */
