@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -102,7 +102,7 @@ FILE *fp=NULL;
 char *cp,***ccc;
 char *s;
 int i;
-ssize_t ii;
+size_t ii;
 /* ----------------- vari voor het starten van gzip ---------------------- */
 int  is_gz=0;
 char *gzip=NULL;
