@@ -1,7 +1,7 @@
 /*
  *  xstring.c  - Tired of writing these things over and over again -
  *
- *  Copyright (C) 2001  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 2001,2015  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ do {
 }
 void cut_after_quote (char *c) 
 {
-char *cp;
+char *cp=c;
 do {
    if(*c=='\"') {
       if(c==cp) 
